@@ -261,6 +261,7 @@ gboolean
 gok_input_open (GokInput *input)
 {
   GtkWidget *window = gok_main_get_main_window ();
+
 #ifdef HAVE_XINPUT  
   if (window && window->window && 
       input && input->info && (input->info->use == IsXExtensionDevice))
@@ -284,10 +285,19 @@ GokInput * gok_input_get_current (void)
   if (input)
     gok_input_free (input);
 
-  gok_gconf_get_string (gconf_client_get_default (), 
-			GOK_GCONF_INPUT_DEVICE, 
-			&input_device_name);
-  input = gok_input_find_by_name (input_device_name, TRUE);
-  g_free (input_device_name);
+  /* was the input device specified on the command line? */
+  input_device_name = gok_main_get_inputdevice_name ();
+  if (input_device_name == NULL) {
+	  /* use gconf setting */
+	  gok_gconf_get_string (gconf_client_get_default (), 
+				GOK_GCONF_INPUT_DEVICE, 
+				&input_device_name);
+	  input = gok_input_find_by_name (input_device_name, TRUE);
+	  g_free (input_device_name);
+  }
+  else
+  {
+      input = gok_input_find_by_name (input_device_name, TRUE);
+  }
   return input;
 }
